# About Me

I'm [Ali Abbas Jaffri](https://aliabbasjaffri.github.io/) and i've been working in the space of MLOps since the fall of 2019. It started off during the course of my Master's thesis at the [Technical University of Munich](https://www.tum.de/en/) but soon grew into a passion. I've been working ever since on the deployment of ML infrastructure.

I started this project in the midst of 2023 after having deliberated on the issue of quick deployment of ML infrastructure. `mlinfra` emerged from my personal need to address these challenges. As I shared my experiences with fellow platform enthusiasts, I realized I was not alone in this journey.

I compiled my insights on deploying various MLOps stacks in different environments into this tool, aspiring to simplify the deployment process across all cloud providers and platform tools. This is an ongoing effort and i really wish to cover more cloud providers and MLOps toolings in the near future. I genuinely hope you find `mlinfra` as useful and transformative as I envisioned and hope you enjoy using it!
